#################################################
# Distribution Dymanics for GDP per worker EU27 #
#################################################

rm(list=ls(all=TRUE))

graphics.off()

library(foreach)
library(doMC)
library(base)
registerDoMC(1)

#Load dataset
load("datasetNUTS2_CE2010_EU27_forGRV_analysis")

#Define variable
  GDPpw <- samplePerWorkerGDP_27
  
  GDPpwRel <- samplePerWorkerGDPRel_27
  colnames(GDPpwRel) <- c(1991:2008)
  
  GDPpwGR <- samplePerWorkerGDPGR_27
  
  numYears <- ncol(GDPpw)

  #Firtst and last year of the sample
  PROD.InitialYear.REL <- (GDPpwRel[,1])
  
  PROD.FinalYear.REL <-  (GDPpwRel[,(numYears)])

    #=========================================================#
    # Density distributions for GDP PER WORKER relative terms #
    #=========================================================#
     
    #Estimate and plot the histogram 
    estimateDensityInitialYear_hist <- hist(PROD.InitialYear.REL,200,freq=FALSE) 
     
    #Estimate and plot the kernel density using "sm" function
    library(sm)
    
    estimateDensityInitialYear_sm <- sm.density(x=PROD.InitialYear.REL,
                                                h=hnorm(PROD.InitialYear.REL),add=TRUE,col="green")
    estimateDensityInitialYear_sm <- sm.density(x=PROD.InitialYear.REL,
                                                h=hcv(PROD.InitialYear.REL),add=TRUE,col="red")
    hist(PROD.InitialYear.REL,80,freq=FALSE,add=TRUE)   
    
	sm.density(PROD.InitialYear.REL, model="normal")

    #Estimate and plot the kernel density using "univariate" function
	#------------------------------------------------------#	
	# Estimation of univariate density via Adaptive Kernel #
  source("univariateDensityAdaptive_Parallel.r")
	#--------------------------------------------------------------#
	# Calculation of the weighted standard deviation of a variable #
	source("weighted.sd.r")

    estimateDensityInitialYear_univ <- univariateDensityAdaptive_Parallel(u=PROD.InitialYear.REL, figure=TRUE,xlim= c(-0.3,2.3))

	#Bootstrap for confidence bands	
    B <-100
    for (b in 1:B){
    	PROD.InitialYear.REL_boot <- sample(PROD.InitialYear.REL, replace=TRUE)
    	#sm.density(PROD.InitialYear.REL_boot, add=TRUE)
    	estimateDensityInitialYear_univ <- univariateDensityAdaptive_Parallel(u=PROD.InitialYear.REL_boot, figure=TRUE,addFigure=TRUE,lwdProvided=0.5, xlim= c(-0.3,2.3))
    }
    #estimateDensityInitialYear_sm <- sm.density(PROD.InitialYear.REL, col="red", lwd=3, add=T)
    estimateDensityInitialYear_univ <- univariateDensityAdaptive_Parallel(u=PROD.InitialYear.REL, figure=TRUE,colProvided="red",lwdProvided=3,addFigure=TRUE)


